summaryrefslogtreecommitdiffstats
path: root/Lib/test/test_cmd_line.py
diff options
context:
space:
mode:
authorBerker Peksag <berker.peksag@gmail.com>2015-05-06 03:33:17 (GMT)
committerBerker Peksag <berker.peksag@gmail.com>2015-05-06 03:33:17 (GMT)
commitce643913a9049953950918b214fb7cef40506be5 (patch)
treef9a84aa003a3af7eaba270e949691b7d71e8d699 /Lib/test/test_cmd_line.py
parent025e9ebd0a0a19f50ca83af6ada0ac65be1fa2a1 (diff)
downloadcpython-ce643913a9049953950918b214fb7cef40506be5.zip
cpython-ce643913a9049953950918b214fb7cef40506be5.tar.gz
cpython-ce643913a9049953950918b214fb7cef40506be5.tar.bz2
Issue #9517: Move script_helper to the support package.
Patch by Christie Wilson.
Diffstat (limited to 'Lib/test/test_cmd_line.py')
-rw-r--r--Lib/test/test_cmd_line.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/Lib/test/test_cmd_line.py b/Lib/test/test_cmd_line.py
index 6ba929c..0feb63f 100644
--- a/Lib/test/test_cmd_line.py
+++ b/Lib/test/test_cmd_line.py
@@ -8,8 +8,8 @@ import shutil
import sys
import subprocess
import tempfile
-from test import script_helper
-from test.script_helper import (spawn_python, kill_python, assert_python_ok,
+from test.support import script_helper
+from test.support.script_helper import (spawn_python, kill_python, assert_python_ok,
assert_python_failure)
@@ -59,7 +59,7 @@ class CmdLineTest(unittest.TestCase):
def test_xoptions(self):
def get_xoptions(*args):
# use subprocess module directly because test.script_helper adds
# "-X faulthandler" to the command line
args = (sys.executable, '-E') + args
args += ('-c', 'import sys; print(sys._xoptions)')
@@ -59,7 +59,7 @@ class CmdLineTest(unittest.TestCase):
def test_xoptions(self):
def get_xoptions(*args):
- # use subprocess module directly because test.script_helper adds
+ # use subprocess module directly because test.support.script_helper adds
# "-X faulthandler" to the command line
args = (sys.executable, '-E') + args